# gtkscintilla.py - wrapper class for the GtkScintilla widget
#
# Copyright (c) 2001  Michele Campeotto <micampe@f2s.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import _gtkscintilla
import gtk; _gtk = gtk; del gtk

import GTKSCINTILLA

class GtkScintilla(_gtk.GtkBin):
    get_type = _gtkscintilla.gtk_scintilla_get_type
    def __init__(self, _obj=None):
        if _obj: self._o = _obj; return
        self._o = _gtkscintilla.gtk_scintilla_new()

# Text retrieval and modification
    def get_text(self):
        return _gtkscintilla.gtk_scintilla_get_text(self._o)
    def set_text(self, text):
        _gtkscintilla.gtk_scintilla_set_text(self._o, text)
    def get_line(self, line):
        """Retrieve the contents of a line.
        """
        return _gtkscintilla.gtk_scintilla_get_line(self._o, line)
    def replace_selection(self, text):
        """Replace the selected text with the argument text.
        """
        _gtkscintilla.gtk_scintilla_seplace_selection(self._o, text)
    def set_read_only(self):
        """Set to read only or read write.
        """
        _gtkscintilla.gtk_scintilla_set_read_only(self._o)
    def insert_text(self, position, text):
        """Insert string at a position.
        """
        _gtkscintilla.gtk_scintilla_insert_text(self._o, position, text)
    def clear_document_style(self):
        """Set all style bytes to 0, remove all folding information.
        """
        _gtkscintilla.gtk_scintilla_clear_document_style(self._o)
    def get_char_at(self, position):
        """Returns the character byte at the position.
        """
        return _gtkscintilla.gtk_scintilla_get_char_at(self._o, position)
# Standard commands
    def cut(self):
        """Cut the selection to the clipboard.
        """
        _gtkscintilla.gtk_scintilla_cut(self._o)
    def copy(self):
        """Copy the selection to the clipboard.
        """
        _gtkscintilla.gtk_scintilla_copy(self._o)
    def paste(self):
        """Paste text from the clipboard.
        
        Paste the contents of the clipboard into the document replacing the selection.
        """
        _gtkscintilla.gtk_scintilla_paste(self._o)
    def can_paste(self):
        """Will a paste succeed?
        """
        return _gtkscintilla.gtk_scintilla_can_paste(self._o)
# Undo and Redo
    def undo(self):
        """Undo one action in the undo history.
        """
        _gtkscintilla.gtk_scintilla_undo(self._o)
    def can_undo(self):
        """Are there any undoable actions in the undo history.
        """
        _gtkscintilla.gtk_scintilla_can_undo(self._o)
    def empty_undo_buffer(self):
        """Delete the undo history.
        """
        _gtkscintilla.gtk_scintilla_empty_undo_buffer(self._o)
    def redo(self):
        """Redoes the next action on the undo history.
        """
        _gtkscintilla.gtk_scintilla_redo(self._o)
    def can_redo(self):
        """Are there any redoable actions in the undo history.
        """
        _gtkscintilla.gtk_scintilla_can_redo(self._o)
    def begin_undo_action(self):
        """Start an undo action.
        
        Start a sequence of actions that is undone and redone as a unit.
        May be nested.
        """
        _gtkscintilla.gtk_scintilla_begin_undo_action(self._o)
    def end_undo_action(self):
        """End an undo action.
        
        End a sequence of actions that is undone and redone as a unit.
        """
        _gtkscintilla.gtk_scintilla_end_undo_action(self._o)
# Selection and information
    def get_text_length(self):
        """Retrieve the number of characters in the document.
        """
        return _gtkscintilla.gtk_scintilla_get_text_length(self._o)
    def get_line_count(self):
        """Returns the number of lines in the document.
        
        There is always at least one.
        """
        return _gtkscintilla.gtk_scintilla_get_line_count(self._o)
    def get_modify(self):
        """Is the document different from when it was last saved?
        """
        return _gtkscintilla.gtk_scintilla_get_modify(self._o)
    def set_selection(self, start, end):
        """Select a range of text.
        """
        _gtkscintilla.gtk_scintilla_set_selection(self._o, start, end)
    def line_from_position(self, position):
        """Retrieve the line containing a position.
        """
        return _gtkscintilla.gtk_scintilla_line_from_position(self._o,
                                                              position)
    def position_from_line(self, line):
        """Retrieve the position at the start of a line.
        """
        return _gtkscintilla.gtk_scintilla_position_from_line(self._o, line)
    def line_length(self, line):
        """Get line length.
        
        How many characters are on a line, not including end of line characters.
        """
        return _gtkscintilla.gtk_scintilla_line_length(self._o, line)
    def get_length(self):
        """Retrieve the number of characters in the document.
        """
        return _gtkscintilla.gtk_scintilla_get_length(self._o)
    def get_current_pos(self):
        """Returns the position of the caret.
        """
        return _gtkscintilla.gtk_scintilla_get_current_pos(self._o)
    def set_current_pos(self, position):
        """Sets the position of the caret.
        """
        _gtkscintilla.gtk_scintilla_set_current_pos(self._o, position)
    def get_selection_start(self):
        """Returns the position at the start of the selection.
        """
        return _gtkscintilla.gtk_scintilla_get_selection_start(self._o)
    def get_selection_end(self):
        """Returns the position at the end of the selection.
        """
        return _gtkscintilla.gtk_scintilla_get_selection_end(self._o)
    def select_all(self):
        """Select all the text in the document.
        """
        _gtkscintilla.gtk_scintilla_select_all(self._o)
    def go_to_line(self, line):
        """Set caret to start of a line and ensure it is visible.
        """
        _gtkscintilla.gtk_scintilla_go_to_line(self._o, line)
    def go_to_pos(self, position):
        """Set caret to a position and ensure it is visible.
        """
        _gtkscintilla.gtk_scintilla_go_to_pos(self._o, position)
    def set_h_scrollbar(self, visible):
        _gtkscintilla.gtk_scintilla_set_h_scrollbar(self._o, visible)
# Searching
    def set_search_anchor(self):
        """Sets the current caret position to be the search anchor.
        """
        _gtkscintilla.gtk_scintilla_search_anchor(self._o)
    set_find_anchor = set_search_anchor
    def search_next(self, flags, text):
        """Find some text starting at the search anchor.   
        """
        _gtkscintilla.gtk_scintilla_search_next(self._o, flags, text)
    find_next = search_next
    def search_prev(self, flags, text):
        """Find some text starting at the search anchor and moving backwards.
        """
        _gtkscintilla.gtk_scintilla_search_prev(self._o, flags, text)
    find_prev = search_prev
# Visible white space
    def set_space_visible(self, visible):
        """Change white space behaviour.
        
        Make white space characters invisible, always visible or visible
        outside indentation.
        """
        _gtkscintilla.gtk_scintilla_set_space_visible(self._o, visible)
# Line endings
    def set_eol_visible(self, visible):
        """Make the end of line characters visible or invisible.
        """
        _gtkscintilla.gtk_scintilla_set_eol_visible(self._o, visible)
# Style definition
    def style_clear_all(self):
        """Clear all the styles.
        
        Clear all the styles and make equivalent to the global default style.
        """
        _gtkscintilla.gtk_scintilla_style_clear_all(self._o)
    def style_reset_default(self):
        """Reset the default style to its state at startup.
        """
        _gtkscintilla.gtk_scintilla_style_reset_default(self._o)
    def style_set_fore(self, style, color):
        """Set the foreground colour of a style.
        """
        _gtkscintilla.gtk_scintilla_style_set_fore(self._o, style, color)
    def style_set_back(self, style, color):
        """Set the background colour of a style.
        """
        _gtkscintilla.gtk_scintilla_style_set_back(self._o, style, color)
    def style_set_bold(self, style, bold):
        """Set a style to be bold or not.
        """
        _gtkscintilla.gtk_scintilla_style_set_bold(self._o, style, bold)
    def style_set_italic(self, style, italic):
        """Set a style to be italic or not.
        """
        _gtkscintilla.gtk_scintilla_style_set_italic(self._o, style, italic)
    def style_set_size(self, style, size):
        """Set the size of characters of a style.
        """
        _gtkscintilla.gtk_scintilla_style_set_size(self._o, style, size)
    def style_set_font(self, style, fontname):
        """Set the font of a style.
        """
        _gtkscintilla.gtk_scintilla_style_set_font(self._o, style, fontname)
    def set_sel_fore(self, use_color, color):
        """Set the foreground colour of the selection.
        
        Set the foreground colour of the selection and whether to use
        this setting.
        """
        _gtkscintilla.gtk_scintilla_set_sel_fore(self._o, use_color, color)
    def set_sel_back(self, use_color, color):
        """Set the background colour of the selection.
        
        Set the background colour of the selection and whether to use
        this setting.
        """
        _gtkscintilla.gtk_scintilla_set_sel_back(self._o, use_color, color)
    def set_caret_fore(self, color):
        """Set the foreground colour of the caret.
        """
        _gtkscintilla.gtk_scintilla_set_caret_fore(self._o, color)
    def set_caret_period(self, period):
        """Set the blinking period of the caret.
        
        Set the time in milliseconds that the caret is on and off. 0 = steady on.
        """
        _gtkscintilla.gtk_scintilla_set_caret_period(self._o, period)
# Margins
    def set_margin_left(self, width):
        """Sets the size in pixels of the left margin.
        """
        _gtkscintilla.gtk_scintilla_set_margin_left(self._o, width)
    def set_margin_right(self, width):
        """Sets the size in pixels of the right margin.
        """
        _gtkscintilla.gtk_scintilla_set_margin_right(self._o, width)
    def set_margin_type(self, margin, type):
        """Set a margin to be either numeric or symbolic.
        """
        _gtkscintilla.gtk_scintilla_set_margin_type(self._o, margin, type)
    def set_margin_width(self, margin, width):
        """Set the width of a margin to a width expressed in pixels.
        """
        _gtkscintilla.gtk_scintilla_set_margin_width(self._o, margin, width)
    def set_margin_sensitive(self, margin, sens):
        """Make a margin sensitive or insensitive to mouse clicks.
        """
        _gtkscintilla.gtk_scintilla_set_margin_sensitive(self._o, margin, sens)
# Other settings
    def set_buffered_draw(self, buffered):
        """Set buffered draw.
        
        If drawing is buffered then each line of text is drawn into a
        bitmap buffer before drawing it to the screen to avoid flicker.
        """
        _gtkscintilla.gtk_scintilla_set_buffered_draw(self._o, buffered)
    def set_tab_width(self, width):
        """Change the tab size.
        
        Change the visible size of a tab to be a multiple of the width of
        a space character.
        """
        _gtkscintilla.gtk_scintilla_set_tab_width(self._o, width)
    def set_indent_width(self, width):
        """Set the number of spaces used for one level of indentation.
        """
        _gtkscintilla.gtk_scintilla_set_indent_width(self._o, width)
    def set_use_tabs(self, use_tabs):
        """Set whether to use spaces instead of true tabs.
        
        Indentation will only use space characters if useTabs is false,
        otherwise it will use a combination of tabs and spaces.
        """
        _gtkscintilla.gtk_scintilla_set_use_tabs(self._o, use_tabs)
    def set_line_indentation(self, line, indentation):
        """Change the indentation of a line to a number of columns.
        """
        _gtkscintilla.gtk_scintilla_set_line_indentation(self._o, line,
                                                        indentation)
    def get_line_indentation(self, line):
        """Retrieve the number of columns that a line is indented.
        """
        return _gtkscintilla.gtk_scintilla_get_line_indentation(self._o, line)
    def get_line_indent_position(self, line):
        """Get line indentation final position.
        
        Retrieve the position before the first non indentation character
        on a line.
        """
        return _gtkscintilla.gtk_scintilla_get_line_indent_position(self._o,
                                                                    line)
    def get_column_from_position(self, position):
        """Get column number from position.
        
        Retrieve the column number of a position, taking tab width into
        account.
        """
        return _gtkscintilla.gtk_scintilla_get_column(self._o, position)
    def grab_focus(self):
        """Set the focus to this Scintilla widget.
        
        You should'nt need to use this since Scintilla 1.34.
        """
        _gtkscintilla.gtk_scintilla_grab_focus(self._o)
# Indentation guides
    def set_indent_visible(self, visible):
        """Show or hide indentation guides.
        """
        _gtkscintilla.gtk_scintilla_set_indent_visible(self._o, visible)
    def highlight_guide(self, column):
        """Set the highlighted indentation guide column.
        """
        gtk_scintilla_highlight_guide(self._o, column)
# Markers
    def marker_define(self, number, symbols):
        """Set the symbol used for a particular marker number.
        """
        _gtkscintilla.gtk_scintilla_marker_define(self._o, number, symbols)
    def marker_set_fore(self, number, colour):
        """Set the foreground colour used for a particular marker number.
        """
        _gtkscintilla.gtk_scintilla_marker_set_fore(self._o, number, colour)
    def marker_set_back(self, number, colour):
        """Set the background colour used for a particular marker number.
        """
        _gtkscintilla.gtk_scintilla_marker_set_back(self._o, number, colour)
    def marker_add(self, line, number):
        """Add a marker to a line.
        """
        _gtkscintilla.gtk_scintilla_marker_add(self._o, line, number)
    def marker_delete(self, line, number):
        """Delete a marker from a line.
        """
        _gtkscintilla.gtk_scintilla_marker_delete(self._o, line, number)
    def marker_delete_all(self, number):
        """Delete all markers with a particular number from all lines.
        """
        _gtkscintilla.gtk_scintilla_marker_delete_all(self._o, number)
    def marker_get(self, line):
        """Get a bit mask of all the markers set on a line.
        """
        return _gtkscintilla.gtk_scintilla_marker_get(self._o, line)
    def marker_next(self, line, mask):
        """Find the next line after lineStart that includes a marker in mask.
        """
        return _gtkscintilla.gtk_scintilla_marker_next(self._o, line, mask)
    def marker_previous(self, line, mask):
        """Find the previous line before lineStart that includes a marker in mask.
        """
        return _gtkscintilla.gtk_scintilla_marker_previous(self._o, line, mask)
# Long lines
    def set_edge_column(self, column):
        """Set the column number of the edge. 
        
        If text goes past the edge then it is highlighted. 
        """
        _gtkscintilla.gtk_scintilla_set_edge_column(self._o, column)
    def set_edge_mode(self, mode):
        """Set page edge mode.
        
        The edge may be displayed by a line (EDGE_LINE) or by highlighting
        text that goes beyond it (EDGE_BACKGROUND) or not displayed at all
        (EDGE_NONE).
        """
        _gtkscintilla.gtk_scintilla_set_edge_mode(self._o, mode)
    def set_edge_color(self, color):
        """Change the colour used in edge indication.
        """
        _gtkscintilla.gtk_scintilla_set_edge_color(self._o, color)
# Lexer
    def set_lexer(self, lexer):
        """Set the lexing language of the document. 
        """
        _gtkscintilla.gtk_scintilla_set_lexer(self._o, lexer)
    def colourise(self, start, end):
        """Colourise a segment of the document using the current lexer.
        """
        _gtkscintilla.gtk_scintilla_colourise(self._o, start, end)
    def set_property(self, key, value):
        """Set up a value that may be used by a lexer for some optional feature.
        """
        _gtkscintilla.gtk_scintilla_set_property(self._o, key, value)
    def set_keywords(self, keywordset, keywords):
        """Set up the key words used by the lexer.
        """
        _gtkscintilla.gtk_scintilla_set_keywords(self._o, keywordset, keywords)
# Notification
    def set_save_point(self):
        """Set save point.
        
        Remember the current position in the undo history as the position at
        which the document was saved.
        """
        _gtkscintilla.gtk_scintilla_set_save_point(self._o)
_gtk._name2cls['GtkScintilla'] = GtkScintilla
